==> haskell-spdx-1.1-3.1-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-spdx.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 spdx
version:              1.1
visibility:           public
id:                   spdx-1.1-6aYq219b4NBAfAfPeeISkP
key:                  spdx-1.1-6aYq219b4NBAfAfPeeISkP
license:              BSD-3-Clause
copyright:            (c) 2015-2018 Oleg Grenrus
maintainer:           Oleg Grenrus <oleg.grenrus@iki.fi>
author:               Oleg Grenrus <oleg.grenrus@iki.fi>
homepage:             https://github.com/phadej/spdx
synopsis:             SPDX license expression language, Extras
description:
    Cabal provides SPDX types. This package provides some extras.

category:             Data
abi:                  50c772e2a4c73aac92a764ef74592e2e
exposed:              True
exposed-modules:      Distribution.SPDX.Extra
import-dirs:          /usr/lib/ghc-9.6.6/site-local/spdx-1.1
library-dirs:         /usr/lib/ghc-9.6.6/site-local/spdx-1.1
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/spdx-1.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-spdx
hs-libraries:         HSspdx-1.1-6aYq219b4NBAfAfPeeISkP
depends:
    Cabal-syntax-3.10.3.0 base-4.18.2.1 containers-0.6.7
    puresat-0.1-5gfK6vpja8QCEiegj8pGS transformers-0.6.1.0

haddock-interfaces:   /usr/share/doc/haskell-spdx/html/spdx.haddock
haddock-html:         /usr/share/doc/haskell-spdx/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-spdx-1.1-4-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-spdx.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 spdx
version:              1.1
visibility:           public
id:                   spdx-1.1-J0K2wB6yEUM6QxnMrKdSBI
key:                  spdx-1.1-J0K2wB6yEUM6QxnMrKdSBI
license:              BSD-3-Clause
copyright:            (c) 2015-2018 Oleg Grenrus
maintainer:           Oleg Grenrus <oleg.grenrus@iki.fi>
author:               Oleg Grenrus <oleg.grenrus@iki.fi>
homepage:             https://github.com/phadej/spdx
synopsis:             SPDX license expression language, Extras
description:
    Cabal provides SPDX types. This package provides some extras.

category:             Data
abi:                  a61ff2ec1521b6a191162a7d11bb2596
exposed:              True
exposed-modules:      Distribution.SPDX.Extra
import-dirs:          /usr/lib/ghc-9.6.6/site-local/spdx-1.1
library-dirs:         /usr/lib/ghc-9.6.6/site-local/spdx-1.1
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/spdx-1.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-spdx
hs-libraries:         HSspdx-1.1-J0K2wB6yEUM6QxnMrKdSBI
depends:
    Cabal-syntax-3.10.3.0 base-4.18.2.1 containers-0.6.7
    puresat-0.1-FSDiV5i4EbG4NhR6TXyjag transformers-0.6.1.0

haddock-interfaces:   /usr/share/doc/haskell-spdx/html/spdx.haddock
haddock-html:         /usr/share/doc/haskell-spdx/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
